"use client";
import { useAppContext } from "@/context/AppContext";
import { Disclosure } from "@headlessui/react";
import React, { SyntheticEvent, useState } from "react";
import { useRouter } from "next/navigation";
import { CloseDisclosure, OpenDisclosure } from "../Icons";
import FormCheck from "../CheckBoxComponent/FormCheck";
import { useSearchParams, usePathname } from "next/navigation";
import useGlobalStore from "@/stores/store";
import { useEffect } from "react";
import Box from "@mui/material/Box";
import Slider from "@mui/material/Slider";
import Link from "next/link";
import {
  carForSale,
  jewellryForSale,
  propertyExtras,
  propertyForSale,
} from "@/utils";
interface IFilterData {
  assetType: string;
  minPrice: number;
  maxPrice: number;
}
export const Main = ({ initialData, params }: any) => {
  // const { filterFunction } = useAppContext();
  const [filterData, setFilterData] = useState<IFilterData>({} as IFilterData);
  const { getPropertyPrice, getCarPrice, getBoatPrice, getJewellryPrice } =
    useAppContext();
  const [url, setUrl] = useState("");
  const router = useRouter(); // Get router object
  const searchParams = useSearchParams();
  const pathname = usePathname();
  const [value, setValue] = React.useState<any>([
    filterData.minPrice,
    filterData.maxPrice,
  ]); // Initial value
  const [priceRange, setPriceRange] = useState<number[]>([
    filterData.minPrice,
    filterData.maxPrice,
  ]);
  const [maxPrice, setMaxPrice] = useState<number>(filterData.maxPrice);
  const [minPrice, setMinPrice] = useState<number>(filterData.minPrice);
  const [selectedFilters, setSelectedFilters] = useState<string[]>([]);
  const [selectedFilters2, setSelectedFilters2] = useState<string[]>([]);
  const [selectedFilters3, setSelectedFilters3] = useState<string[]>([]);
  const [selectedFilters4, setSelectedFilters4] = useState<string[]>([]);
  const [selectedFilters5, setSelectedFilters5] = useState<string[]>([]);

  const [sortOrder, setSortOrder] = useState<string | null>(
    searchParams ? searchParams.get("propertyType") : ""
  );
  const [interiorshow, setInteriorShow] = useState(false);
  const [technical, setTechnical] = useState(false);
  const [extras, setExtras] = useState(false);
  const [show, setShow] = useState(false);
  const check = url.split("/")[3]?.split("?")[0];

  useEffect(() => {
    setApiData(initialData);
    if (sortOrder !== null) {
      const params = new URLSearchParams(searchParams?.toString());
      params.set("propertyType", sortOrder);

      const newUrl = `${pathname}?${params.toString()}`;
      window.history.pushState(null, "", newUrl);
    }
    // Function to be executed when search parameters change
    console.log("Search parameters have changed:", searchParams?.toString());
    console.log(check, "check");

    // For example, you can trigger an action or update state
    if (typeof window !== "undefined") {
      const currentUrl = window.location.href;
      setUrl(currentUrl);
    }

    const localStorageFilterData: string =
      localStorage.getItem("filterData") || "";
    if (localStorageFilterData) {
      const filterData: IFilterData = JSON.parse(localStorageFilterData);
      setValue([filterData.minPrice, filterData.maxPrice]);
      setMinPrice(filterData.minPrice);
      setMaxPrice(filterData.maxPrice);
    } else {
      const data = {
        assetType: check,
        maxPrice,
        minPrice,
      };
      setFilterData(data);
      localStorage.setItem("filterData", JSON.stringify(data));
      setValue([handlemin(), handlemax()]);
      setPriceRange([Number(handlemin()), Number(handlemax())]);
    }
    if (maxPrice != filterData.minPrice || minPrice != filterData.maxPrice) {
      updateSortingForPrice();
    }
  }, [maxPrice, minPrice, sortOrder]);
  // }, [value, searchParams, check, sortOrder, pathname]);
  // console.log(minPrice, maxPrice, "value");

  const updateSortingForPropertyType = (newSortOrder: string) => {
    // setSortOrder(newSortOrder);
    updateSearchParams("propertyType", newSortOrder);
  };

  const handleChange = (
    event: Event | SyntheticEvent<Element, Event>,
    value: number | number[]
  ) => {
    event.preventDefault();
    setValue(value);
  };
  const handleChangeCommitted = (
    event: Event | SyntheticEvent<Element, Event>,
    value: number | number[]
  ) => {
    event.preventDefault();
    if (Array.isArray(value)) {
      const data = {
        assetType: check,
        maxPrice: value[1],
        minPrice: value[0],
      };
      localStorage.setItem("filterData", JSON.stringify(data));
      setMaxPrice(value[1]);
      setMinPrice(value[0]);
      setPriceRange(value); // 😊
    }
  };

  const setApiData = useGlobalStore((state) => state.setApiData);

  const apiData = useGlobalStore((state) => state.apiData);

  const updateSearchParams = (key: any, value: any) => {
    const params = new URLSearchParams(searchParams ? searchParams : "");
    params.set(key, value);
    window.history.pushState(null, "", `?${params.toString()}`);
  };

  const updateSortingForProperty = (sortOrder: any, e: any) => {
    e.preventDefault();
    updateSearchParams("assetType", sortOrder);
  };

  const updateSortingForBedrooms = (sortOrder: any) => {
    updateSearchParams("bedrooms", sortOrder);
  };

  const updateSortingForGrams = (sortOrder: any) => {
    updateSearchParams("grams", sortOrder);
  };

  const updateSortingForCountry = (sortOrder: any) => {
    updateSearchParams("country", sortOrder);
  };

  const updateSortingForCity = (sortOrder: any) => {
    updateSearchParams("city", sortOrder);
  };

  function updateSortingForCategories(sortOrder: any) {
    updateSearchParams("categories", sortOrder);
  }

  const updateSortingForPrice = () => {
    const params = new URLSearchParams(searchParams ? searchParams : "");
    if (value) {
      params.set("minPrice", value[0]);
      params.set("maxPrice", value[1]);
      window.history.pushState(null, "", `?${params.toString()}`);
    }
  };

  function updateSortingForInteriorColor() {
    updateSearchParams("interiorColor", selectedFilters2.join(","));
  }

  function updateSortingForExteriorColor() {
    updateSearchParams("exteriorColor", selectedFilters.join(","));
  }

  function updateSortingForTechnicalFeatures() {
    updateSearchParams("technicalFeatures", selectedFilters3.join(","));
  }

  function updateSortingForCarExtra() {
    updateSearchParams("extras", selectedFilters4.join(","));
  }

  const updateSortingForNieghbourHood = (value: any) => {
    updateSearchParams("neighbourhood", value);
  };

  const updateSortingForExtras = () => {
    updateSearchParams("facilities", selectedFilters.join(","));
  };

  const updateSortingForMaterial = () => {
    updateSearchParams("materials", selectedFilters5.join(","));
  };

  const updateSortingForTitle = (sortOrder: any) => {
    updateSearchParams("title", sortOrder);
  };

  const handleClick = (value: any, e: any, item?: any) => {
    e.preventDefault();
    // setCheck(value);
    if (item === "Property For Sale") {
      router.push(`/${value}?assetType=${item}`);
    } else if (item === "Property For Lease") {
      router.push(`/${value}?assetType=${item}`);
    } else {
      router.push(`/${value}`);
    }
  };

  const handleCheckboxChange = (event: any) => {
    const { value, checked } = event.target;
    if (checked) {
      setSelectedFilters([...selectedFilters, value]);
    }
  };

  const handleCheckboxChange2 = (event: any) => {
    const { value, checked } = event.target;
    if (checked) {
      setSelectedFilters2([...selectedFilters2, value]);
    }
  };

  const handleCheckboxChange3 = (event: any) => {
    const { value, checked } = event.target;
    if (checked) {
      setSelectedFilters3([...selectedFilters3, value]);
    }
  };

  const handleCheckboxChange4 = (event: any) => {
    const { value, checked } = event.target;
    if (checked) {
      setSelectedFilters4([...selectedFilters4, value]);
    }
  };

  const handleCheckboxChange5 = (event: any) => {
    const { value, checked } = event.target;
    // Logic to update selectedFilters based on checked state and value
    if (checked) {
      setSelectedFilters5([...selectedFilters5, value]);
    }
  };

  const handlemax = () => {
    if (check === "property") {
      return Number(getPropertyPrice?.highestPrice) || 1000; // Example default value
    } else if (check === "car") {
      return Number(getCarPrice?.highestPrice) || 1000; // Example default value
    } else if (check === "boat") {
      return Number(getBoatPrice?.highestPrice) || 1000; // Example default value
    } else if (check === "jewelry") {
      return Number(getJewellryPrice?.highestPrice) || 1000; // Example default value
    }
  };

  const handlemin = () => {
    if (check === "property") {
      return Number(getPropertyPrice?.lowestPrice) || 0; // Example default value
    } else if (check === "car") {
      return Number(getCarPrice?.lowestPrice) || 0; // Example default value
    } else if (check === "boat") {
      return Number(getBoatPrice?.lowestPrice) || 0; // Example default value
    } else if (check === "jewelry") {
      return Number(getJewellryPrice?.lowestPrice) || 0; // Example default value
    }
  };

  return (
    <div className="flex flex-wrap lg:flex-nowrap gap-5 py-5">
      <aside className="custom-shadow w-full xl:w-auto lg:min-w-[385px]">
        <span className="border-b block px-10 py-4 text-xl text-darkGray ">
          Side Menu
        </span>
        <div className="border-b ">
          <div className="px-10 py-3">
            <div className="mb-3">
              <Disclosure as="div" className={`disclosure`} defaultOpen={false}>
                {({ open }) => (
                  <>
                    {/* <Link href="/property"> */}
                    <Disclosure.Button
                      className={`w-full bg-whiteSmoke rounded py-3 px-6 gap-4 justify-between items-center flex ${
                        open && "mb-3"
                      }`}
                    >
                      <span
                        className="text-[22px] text-reefGold"
                        onClick={(e) => {
                          handleClick("property", e, "Property For Sale");
                        }}
                      >
                        Property For Sale
                      </span>
                      <span className="flex-shrink-0">
                        {open ? (
                          <OpenDisclosure className="text-[#8D7C3B]" />
                        ) : (
                          <CloseDisclosure className="text-[#8D7C3B]" />
                        )}
                      </span>
                    </Disclosure.Button>
                    {/* </Link> */}

                    <Disclosure.Panel as="div" className="px-8 text-lg">
                      <Disclosure as="div" className={`disclosure`}>
                        {({ open }) => (
                          <>
                            <Disclosure.Button
                              className={`w-full rounded py-3 px-6 gap-4 justify-between items-center flex ${
                                open && "mb-3"
                              }`}
                            >
                              <span className="text-xl text-reefGold">
                                Residential
                              </span>
                              <span className="flex-shrink-0">
                              {open ? (
                                <OpenDisclosure className="text-[#8D7C3B]" />
                              ) : (
                                <CloseDisclosure className="text-[#8D7C3B]" />
                              )}
                              </span>
                            </Disclosure.Button>
                            <Disclosure.Panel
                              as="div"
                              className="flex flex-col gap-1 px-8 text-lg"
                            >
                              {propertyForSale.Residential?.map((obj, _) => (
                                <button
                                  key={obj.id}
                                  className="cursor-pointer text-left"
                                  onClick={() =>
                                    updateSortingForPropertyType(obj.value)
                                  }
                                >
                                  {obj.value}
                                </button>
                              ))}
                            </Disclosure.Panel>
                          </>
                        )}
                      </Disclosure>
                      <Disclosure as="div" className={`disclosure`}>
                        {({ open }) => (
                          <>
                            <Disclosure.Button
                              className={`w-full rounded py-3 px-6 gap-4 justify-between items-center flex ${
                                open && "mb-3"
                              }`}
                            >
                              <span className="text-xl">Commercial</span>
                              <span className="flex-shrink-0">
                              {open ? (
                                <OpenDisclosure className="text-[#8D7C3B]" />
                              ) : (
                                <CloseDisclosure className="text-[#8D7C3B]" />
                              )}
                              </span>
                            </Disclosure.Button>
                            <Disclosure.Panel
                              as="div"
                              className="flex flex-col gap-1 px-8 text-lg"
                            >
                              {propertyForSale?.Commercial?.map((obj, _) => (
                                <p
                                  key={obj.id}
                                  className="cursor-pointer text-left"
                                  onClick={() =>
                                    updateSortingForPropertyType(obj.value)
                                  }
                                >
                                  {obj.value}
                                </p>
                              ))}
                            </Disclosure.Panel>
                          </>
                        )}
                      </Disclosure>
                      <Disclosure as="div" className={`disclosure`}>
                        {({ open }) => (
                          <>
                            <Disclosure.Button
                              className={`w-full rounded py-3 px-6 gap-4 justify-between items-center flex ${
                                open && "mb-3"
                              }`}
                            >
                              <span className="text-xl">
                                {propertyForSale.land}
                              </span>
                            </Disclosure.Button>
                          </>
                        )}
                      </Disclosure>
                      <Disclosure as="div" className={`disclosure`}>
                        {({ open }) => (
                          <>
                            <Disclosure.Button
                              className={`w-full rounded py-3 px-6 gap-4 justify-between items-center flex ${
                                open && "mb-3"
                              }`}
                            >
                              <span className="text-xl">
                                {propertyForSale.multiple}
                              </span>
                              <span className="flex-shrink-0"></span>
                            </Disclosure.Button>
                          </>
                        )}
                      </Disclosure>
                    </Disclosure.Panel>
                  </>
                )}
              </Disclosure>
            </div>
            <div className="mb-3">
              <Disclosure as="div" className={`mb-3`}>
                {({ open }) => (
                  <>
                    <Disclosure.Button
                      className={`w-full bg-whiteSmoke rounded py-3 px-6 gap-4 justify-between items-center flex ${
                        open && "mb-3"
                      }`}
                    >
                      <span
                        className="text-[22px]"
                        onClick={(e) => {
                          handleClick("property", e, "Property For Lease");
                          // updateSortingForProperty("Property For Lease", e);
                        }}
                      >
                        Property For Lease
                      </span>
                      <span className="flex-shrink-0">
                        {open ? (
                          <OpenDisclosure className="text-[#8D7C3B]" />
                        ) : (
                          <CloseDisclosure className="text-[#8D7C3B]" />
                        )}
                      </span>
                    </Disclosure.Button>
                    <Disclosure.Panel as="div" className="px-8 text-lg">
                      <Disclosure as="div" className={`disclosure`}>
                        {({ open }) => (
                          <>
                            <Disclosure.Button
                              className={`w-full rounded py-3 px-6 gap-4 justify-between items-center flex ${
                                open && "mb-3"
                              }`}
                            >
                              <span className="text-xl text-reefGold">
                                Residential
                              </span>
                              <span className="flex-shrink-0">
                              {open ? (
                                <OpenDisclosure className="text-[#8D7C3B]" />
                              ) : (
                                <CloseDisclosure className="text-[#8D7C3B]" />
                              )}
                              </span>
                            </Disclosure.Button>
                            <Disclosure.Panel
                              as="div"
                              className="flex flex-col gap-1 px-8 text-lg"
                            >
                              {propertyForSale.Residential?.map((obj, _) => (
                                <button
                                  key={obj.id}
                                  className="cursor-pointer text-left"
                                  onClick={() =>
                                    updateSortingForPropertyType(obj.value)
                                  }
                                >
                                  {obj.value}
                                </button>
                              ))}
                            </Disclosure.Panel>
                          </>
                        )}
                      </Disclosure>
                      <Disclosure as="div" className={`disclosure`}>
                        {({ open }) => (
                          <>
                            <Disclosure.Button
                              className={`w-full rounded py-3 px-6 gap-4 justify-between items-center flex ${
                                open && "mb-3"
                              }`}
                            >
                              <span className="text-xl">Commercial</span>
                              <span className="flex-shrink-0">
                              {open ? (
                                <OpenDisclosure className="text-[#8D7C3B]" />
                              ) : (
                                <CloseDisclosure className="text-[#8D7C3B]" />
                              )}
                              </span>
                            </Disclosure.Button>
                            <Disclosure.Panel
                              as="div"
                              className="flex flex-col gap-1 px-8 text-lg"
                            >
                              {propertyForSale?.Commercial?.map((obj, _) => (
                                <button
                                  key={obj.id}
                                  className="cursor-pointer text-left"
                                  onClick={() =>
                                    updateSortingForPropertyType(obj.value)
                                  }
                                >
                                  {obj.value}
                                </button>
                              ))}
                            </Disclosure.Panel>
                          </>
                        )}
                      </Disclosure>
                    </Disclosure.Panel>
                  </>
                )}
              </Disclosure>
              <Disclosure as="div" className={`mb-3`}>
                {({ open }) => (
                  <>
                    <Disclosure.Button
                      className={`w-full bg-whiteSmoke rounded py-3 px-6 gap-4 justify-between items-center flex ${
                        open && "mb-3"
                      }`}
                    >
                      {/* <Link href="/car"> */}
                      <span
                        onClick={(e) => {
                          handleClick("car", e);
                        }}
                        className="text-[22px]"
                      >
                        Car For Sale
                      </span>
                      {/* </Link> */}
                      <span className="flex-shrink-0">
                        {open ? (
                          <OpenDisclosure className="text-[#8D7C3B]" />
                        ) : (
                          <CloseDisclosure className="text-[#8D7C3B]" />
                        )}
                      </span>
                    </Disclosure.Button>
                    <Disclosure.Panel
                      as="div"
                      className="flex flex-col gap-1 px-8 text-lg"
                    >
                      {carForSale.map((obj, _) => (
                        <button
                          key={obj.id}
                          className="cursor-pointer text-left"
                          // onClick={() => updateSorting(obj.value)}
                        >
                          {obj.value}
                        </button>
                      ))}
                    </Disclosure.Panel>
                  </>
                )}
              </Disclosure>
              <Disclosure as="div" className={`mb-3`}>
                {({ open }) => (
                  <>
                    <Disclosure.Button
                      className={`w-full bg-whiteSmoke rounded py-3 px-6 gap-4 justify-between items-center flex ${
                        open && "mb-3"
                      }`}
                    >
                      <span
                        onClick={(e) => handleClick("jewelry", e)}
                        className="text-[22px]"
                      >
                        Jewellery For Sale
                      </span>

                      <span className="flex-shrink-0">
                        {open ? (
                          <OpenDisclosure className="text-[#8D7C3B]" />
                        ) : (
                          <CloseDisclosure className="text-[#8D7C3B]" />
                        )}
                      </span>
                    </Disclosure.Button>
                    <Disclosure.Panel
                      as="div"
                      className="flex flex-col gap-1 px-8 text-lg"
                    >
                      <Disclosure as="div" defaultOpen={false}>
                        {({ open }) => (
                          <>
                            <Disclosure.Button
                              className={`w-full rounded py-3 px-6 gap-4 justify-between items-center flex`}
                            >
                              <span className="text-xl text-reefGold">
                                Necklace
                              </span>
                              <span className="flex-shrink-0">
                              {open ? (
                                <OpenDisclosure className="text-[#8D7C3B]" />
                              ) : (
                                <CloseDisclosure className="text-[#8D7C3B]" />
                              )}
                              </span>
                            </Disclosure.Button>
                            <Disclosure.Panel
                              as="div"
                              className="flex flex-col gap-1 px-8 text-lg"
                            >
                              {jewellryForSale.Necklace.map((obj, _) => (
                                <button
                                  key={obj.id}
                                  className="cursor-pointer text-left"
                                  onClick={() =>
                                    updateSortingForTitle(obj.value)
                                  }
                                >
                                  {obj.value}
                                </button>
                              ))}
                            </Disclosure.Panel>
                          </>
                        )}
                      </Disclosure>
                    </Disclosure.Panel>
                  </>
                )}
              </Disclosure>
              <Disclosure as="div" className={`mb-3`}>
                {({ open }) => (
                  <>
                    <Disclosure.Button
                      className={`w-full bg-whiteSmoke rounded py-3 px-6 gap-4 justify-between items-center flex ${
                        open && "mb-3"
                      }`}
                    >
                      <span
                        onClick={(e) => handleClick("boat", e)}
                        className="text-[22px]"
                      >
                        Boats For Sale
                      </span>
                      <span className="flex-shrink-0">
                        {open ? (
                          <OpenDisclosure className="text-[#8D7C3B]" />
                        ) : (
                          <CloseDisclosure className="text-[#8D7C3B]" />
                        )}
                      </span>
                    </Disclosure.Button>
                    <Disclosure.Panel as="div" className="px-8 text-lg">
                      <Disclosure as="div" defaultOpen={true}>
                        {({ open }) => (
                          <>
                            <Disclosure.Button
                              className={`w-full rounded py-3 px-6 gap-4 justify-between items-center flex`}
                            >
                              <span className="text-xl text-reefGold">
                                Power Boats
                              </span>
                              <span className="flex-shrink-0">
                              {open ? (
                                <OpenDisclosure className="text-[#8D7C3B]" />
                              ) : (
                                <CloseDisclosure className="text-[#8D7C3B]" />
                              )}
                              </span>
                            </Disclosure.Button>
                            <Disclosure.Panel
                              as="div"
                              className="flex flex-col gap-1 px-8 text-lg"
                            >
                              <p
                                onClick={() =>
                                  updateSortingForTitle("Motor Boat")
                                }
                                className="cursor-pointer"
                              >
                                Motor Boat
                              </p>
                              <p
                                onClick={() =>
                                  updateSortingForTitle("Bayliner")
                                }
                                className="cursor-pointer"
                              >
                                Bayliner
                              </p>
                              <p
                                onClick={() =>
                                  updateSortingForTitle("Everglades Boats")
                                }
                                className="cursor-pointer"
                              >
                                Everglades Boats
                              </p>
                              <p
                                onClick={() => updateSortingForTitle("Viking")}
                                className="cursor-pointer"
                              >
                                Viking
                              </p>
                              <p
                                onClick={() =>
                                  updateSortingForTitle("Cruise Boat")
                                }
                                className="cursor-pointer"
                              >
                                Cruise Boats
                              </p>
                              <p
                                onClick={() =>
                                  updateSortingForTitle("Bass Boat")
                                }
                                className="cursor-pointer"
                              >
                                Bass Boats
                              </p>
                              <p
                                onClick={() =>
                                  updateSortingForTitle("Pontoon Boat")
                                }
                                className="cursor-pointer"
                              >
                                Pontoon Boats
                              </p>
                              <p
                                onClick={() =>
                                  updateSortingForTitle("Bay Boat")
                                }
                                className="cursor-pointer"
                              >
                                Bay Boats
                              </p>
                            </Disclosure.Panel>
                          </>
                        )}
                      </Disclosure>
                    </Disclosure.Panel>
                  </>
                )}
              </Disclosure>
            </div>
          </div>
        </div>
        <div className="border-b">
          <div className="px-10 py-3">
            <span className="mb-3 block text-xl">Filter by price</span>

            <Box sx={{ width: 300 }}>
              <Slider
                getAriaLabel={() => "Minimum distance"}
                value={value}
                max={handlemax()}
                min={handlemin()}
                onChange={handleChange}
                onChangeCommitted={handleChangeCommitted}
                step={50}
                valueLabelDisplay="auto"
                getAriaValueText={() => "Price range"}
              />
            </Box>
            {check === "property" ? (
              <>
                <p className="text-xs">
                  Price : ${getPropertyPrice?.lowestPrice} - $
                  {getPropertyPrice?.highestPrice}
                </p>
              </>
            ) : null}
            {check === "car" ? (
              <>
                <p className="text-xs">
                  Price : ${getCarPrice?.lowestPrice} - $
                  {getCarPrice?.highestPrice}
                </p>
              </>
            ) : null}
            {check === "boat" ? (
              <>
                <p className="text-xs">
                  Price : ${getBoatPrice?.lowestPrice} - $
                  {getBoatPrice?.highestPrice}
                </p>
              </>
            ) : null}
            {check === "jewelry" ? (
              <>
                <p className="text-xs">
                  Price : ${getJewellryPrice?.lowestPrice} - $
                  {getJewellryPrice?.highestPrice}
                </p>
              </>
            ) : null}

            {/*    <div className="flex justify-center">
              <button onClick={updateSortingForPrice} className="bg-reefGold  py-2 px-6 rounded mt-3 text-white">
                Filter
              </button>
            </div> */}
          </div>
        </div>
        <div className="border-b">
          <div className="px-10 py-3">
            <p className="text-xl mb-3">Filter by Country</p>
            <Disclosure as="div" className={`disclosure`}>
              {({ open }) => (
                <>
                  <Disclosure.Button
                    className={`w-full bg-whiteSmoke rounded py-3 px-6 gap-4 justify-between items-center flex ${
                      open && "mb-3"
                    }`}
                  >
                    <span className="text-base">United Arab Emirate</span>
                    <span className="flex-shrink-0">
                      {open ? (
                        <CloseDisclosure className="text-[#8D7C3B]" />
                      ) : (
                        <OpenDisclosure className="text-[#8D7C3B]" />
                      )}
                    </span>
                  </Disclosure.Button>
                  <Disclosure.Panel as="div" className="px-8 text-sm">
                    <p
                      className="cursor-pointer"
                      onClick={() => updateSortingForCountry("USA")}
                    >
                      USA
                    </p>
                    <p
                      className="cursor-pointer"
                      onClick={() => updateSortingForCountry("UK")}
                    >
                      UK
                    </p>
                  </Disclosure.Panel>
                </>
              )}
            </Disclosure>
          </div>
        </div>
        <div className="border-b">
          <div className="px-10 py-3">
            <p className="text-xl mb-3">Filter by City</p>
            <Disclosure as="div" className={`disclosure`}>
              {({ open }) => (
                <>
                  <Disclosure.Button
                    className={`w-full bg-whiteSmoke rounded py-3 px-6 gap-4 justify-between items-center flex ${
                      open && "mb-3"
                    }`}
                  >
                    <span className="text-base cursor-pointer">Dubai</span>
                    <span className="flex-shrink-0">
                      {open ? (
                        <CloseDisclosure className="text-[#8D7C3B]" />
                      ) : (
                        <OpenDisclosure className="text-[#8D7C3B]" />
                      )}
                    </span>
                  </Disclosure.Button>
                  <Disclosure.Panel
                    as="div"
                    className="px-8 text-sm cursor-pointer"
                  >
                    <p onClick={() => updateSortingForCity("Dubai")}>Dubai</p>
                    <p>Dubai</p>
                  </Disclosure.Panel>
                </>
              )}
            </Disclosure>
          </div>
        </div>
        <div className="border-b">
          <div className="px-10 py-3">
            <p className="text-xl mb-3">Filter by Categories</p>
            <Disclosure as="div" className={`disclosure`}>
              {({ open }) => (
                <>
                  <Disclosure.Button
                    className={`w-full bg-whiteSmoke rounded py-3 px-6 gap-4 justify-between items-center flex ${
                      open && "mb-3"
                    }`}
                  >
                    <span className="text-base">Cars</span>
                    <span className="flex-shrink-0">
                      {open ? (
                        <CloseDisclosure className="text-[#8D7C3B]" />
                      ) : (
                        <OpenDisclosure className="text-[#8D7C3B]" />
                      )}
                    </span>
                  </Disclosure.Button>
                  <Disclosure.Panel as="div" className="px-8 text-sm">
                    <p
                      className="cursor-pointer"
                      onClick={() => updateSortingForCategories("Land")}
                    >
                      Land
                    </p>
                    <p
                      className="cursor-pointer"
                      onClick={() => updateSortingForCategories("Jewellary")}
                    >
                      Jewellary
                    </p>
                  </Disclosure.Panel>
                </>
              )}
            </Disclosure>
          </div>
        </div>
        <div className="border-b">
          <div className="px-10 py-3">
            <p
              className="text-xl mb-3"
              onClick={(e) => updateSortingForProperty("neighbourhood", e)}
            >
              Neighbourhood
            </p>
            <Disclosure as="div" className={`disclosure`}>
              {({ open }) => (
                <>
                  <Disclosure.Button
                    className={`w-full bg-whiteSmoke rounded py-3 px-6 gap-4 justify-between items-center flex ${
                      open && "mb-3"
                    }`}
                  >
                    <span className="text-base">Neighbourhood</span>
                    <span className="flex-shrink-0">
                      {open ? (
                        <CloseDisclosure className="text-[#8D7C3B]" />
                      ) : (
                        <OpenDisclosure className="text-[#8D7C3B]" />
                      )}
                    </span>
                  </Disclosure.Button>
                  <Disclosure.Panel as="div" className="px-8 text-sm">
                    <p
                      className="cursor-pointer"
                      onClick={() => updateSortingForNieghbourHood("Land")}
                    >
                      Land
                    </p>
                    <p
                      className="cursor-pointer"
                      onClick={() => updateSortingForNieghbourHood("Jewellary")}
                    >
                      Jewellary
                    </p>
                  </Disclosure.Panel>
                </>
              )}
            </Disclosure>
          </div>
        </div>
        {check === "property" ? (
          <>
            <div className="border-b">
              <div className="px-10 py-3">
                <p className="text-xl mb-3">Bedrooms</p>
                <Disclosure as="div" className={`disclosure`}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full bg-whiteSmoke rounded py-3 px-6 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span className="text-base">5</span>
                        <span className="flex-shrink-0">
                          {open ? (
                            <CloseDisclosure className="text-[#8D7C3B]" />
                          ) : (
                            <OpenDisclosure className="text-[#8D7C3B]" />
                          )}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel as="div" className="px-8 text-sm">
                        <p onClick={() => updateSortingForBedrooms(2)}>2</p>
                        <p onClick={() => updateSortingForBedrooms(3)}>3</p>
                        <p onClick={() => updateSortingForBedrooms(4)}>4</p>
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
              </div>
            </div>
          </>
        ) : null}

        {check === "property" ? (
          <>
            <div className="border-b ">
              <div className="px-10 py-3">
                <div className="mb-3">
                  <Disclosure as="div" className={`mb-3`} defaultOpen={true}>
                    {({ open }) => (
                      <>
                        <Disclosure.Button
                          className={` w-full rounded py-3 px-6 gap-4 justify-between items-center flex ${
                            open && "mb-3"
                          }`}
                        >
                          <span className="text-xl">Extras</span>
                          <span className="flex-shrink-0">
                            {open ? (
                              <CloseDisclosure className="text-[#8D7C3B]" />
                            ) : (
                              <OpenDisclosure className="text-[#8D7C3B]" />
                            )}
                          </span>
                        </Disclosure.Button>
                        <Disclosure.Panel
                          as="div"
                          className=" bg-whiteSmoke px-4 py-3 text-xs"
                        >
                          <div className="grid grid-cols-2 gap-3">
                            {propertyExtras?.map((item, i) => (
                              <div key={item.id}>
                                <FormCheck
                                  onChange={(e) => handleCheckboxChange(e)}
                                  label={item.value}
                                  value={item.value}
                                  id={`${item.id}`}
                                />
                              </div>
                            ))}
                          </div>

                          {/* <div className=" flex justify-center">
                        <button
                          onClick={() => {
                            setExtras(!extras);
                          }}
                          className="bg-white  py-2 px-6 rounded mt-3 underline text-reefGold"
                        >
                          {extras ? "View Less" : "View More"}
                        </button>
                      </div> */}
                          <div className="flex justify-center">
                            <button
                              onClick={() => updateSortingForExtras()}
                              className="bg-reefGold  py-2 px-6 rounded mt-3 text-white"
                            >
                              Filter
                            </button>
                          </div>
                        </Disclosure.Panel>
                      </>
                    )}
                  </Disclosure>
                </div>
              </div>
            </div>
          </>
        ) : null}

        {check === "car" || check === "boat" ? (
          <>
            <div className="border-b">
              <div className="px-10 py-3">
                <div className="mb-3">
                  <Disclosure as="div" className={`mb-3`} defaultOpen={true}>
                    {({ open }) => (
                      <>
                        <Disclosure.Button
                          className={` w-full rounded py-3 px-6 gap-4 justify-between items-center flex ${
                            open && "mb-3"
                          }`}
                        >
                          <span className="text-xl">Exterior Color</span>
                          <span className="flex-shrink-0">
                            {open ? (
                              <CloseDisclosure className="text-[#8D7C3B]" />
                            ) : (
                              <OpenDisclosure className="text-[#8D7C3B]" />
                            )}
                          </span>
                        </Disclosure.Button>
                        <Disclosure.Panel
                          as="div"
                          className=" bg-whiteSmoke px-4 py-3 text-xs"
                        >
                          <>
                            <div className="grid grid-cols-4 gap-3">
                              <FormCheck
                                onChange={(e) => handleCheckboxChange(e)}
                                value="Black"
                                label="Black"
                                id="1"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange(e)}
                                value="Purple"
                                label="Purple"
                                id="2"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange(e)}
                                value="Brown"
                                label="Brown"
                                id="3"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange(e)}
                                value="Light"
                                label="Light"
                                id="4"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange(e)}
                                value="Blue"
                                label="Blue"
                                id="5"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange(e)}
                                value="Red"
                                label="Red"
                                id="6"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange(e)}
                                value="Silver"
                                label="Silver"
                                id="7"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange(e)}
                                value="Dark"
                                label="Dark"
                                id="8"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange(e)}
                                value="Pink"
                                label="Pink"
                                id="9"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange(e)}
                                value="Green"
                                label="Green"
                                id="10"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange(e)}
                                value="Orange"
                                label="Orange"
                                id="11"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange(e)}
                                value="White"
                                label="White"
                                id="12"
                              />
                            </div>
                            {show && (
                              <div className="grid grid-cols-4 gap-3 mt-3">
                                <FormCheck
                                  onChange={(e) => handleCheckboxChange(e)}
                                  value="Yellow"
                                  label="Yellow"
                                  id="13"
                                />
                                <FormCheck
                                  onChange={(e) => handleCheckboxChange(e)}
                                  value="Aqua"
                                  label="Aqua"
                                  id="14"
                                />
                                <FormCheck
                                  onChange={(e) => handleCheckboxChange(e)}
                                  value="Beige"
                                  label="Beige"
                                  id="15"
                                />
                                <FormCheck
                                  onChange={(e) => handleCheckboxChange(e)}
                                  value="Grey"
                                  label="Grey"
                                  id="16"
                                />
                                <FormCheck
                                  onChange={(e) => handleCheckboxChange(e)}
                                  value="Gold"
                                  label="Gold"
                                  id="17"
                                />
                                <FormCheck
                                  onChange={(e) => handleCheckboxChange(e)}
                                  value="Teal"
                                  label="Teal"
                                  id="18"
                                />
                                <FormCheck
                                  onChange={(e) => handleCheckboxChange(e)}
                                  value="Tan"
                                  label="Tan"
                                  id="19"
                                />
                                <FormCheck
                                  onChange={(e) => handleCheckboxChange(e)}
                                  value="DarkKhaki"
                                  label="DarkKhaki"
                                  id="20"
                                />
                                <FormCheck
                                  onChange={(e) => handleCheckboxChange(e)}
                                  value="Burgundy"
                                  label="Burgundy"
                                  id="21"
                                />
                                <FormCheck
                                  onChange={(e) => handleCheckboxChange(e)}
                                  value="DarkBlue"
                                  label="DarkBlue"
                                  id="22"
                                />
                                <FormCheck
                                  onChange={(e) => handleCheckboxChange(e)}
                                  value="DarkGreen"
                                  label="DarkGreen"
                                  id="23"
                                />
                                <FormCheck
                                  onChange={(e) => handleCheckboxChange(e)}
                                  value="DarkCyan"
                                  label="DarkCyan"
                                  id="24"
                                />
                              </div>
                            )}
                            <div className=" flex justify-center">
                              <button
                                onClick={() => {
                                  setShow(!show);
                                }}
                                className="bg-white  py-2 px-6 rounded mt-3 underline text-reefGold"
                              >
                                {show ? "View Less" : "View More"}
                              </button>
                            </div>
                            <div className="flex justify-center">
                              <button
                                onClick={() => updateSortingForExteriorColor()}
                                className="bg-reefGold  py-2 px-6 rounded mt-3 text-white"
                              >
                                Filter
                              </button>
                            </div>
                          </>
                        </Disclosure.Panel>
                      </>
                    )}
                  </Disclosure>
                  <Disclosure as="div" className={`mb-3`} defaultOpen={true}>
                    {({ open }) => (
                      <>
                        <Disclosure.Button
                          className={` w-full rounded py-3 px-6 gap-4 justify-between items-center flex ${
                            open && "mb-3"
                          }`}
                        >
                          <span className="text-xl">Interior Color</span>
                          <span className="flex-shrink-0">
                            {open ? (
                              <CloseDisclosure className="text-[#8D7C3B]" />
                            ) : (
                              <OpenDisclosure className="text-[#8D7C3B]" />
                            )}
                          </span>
                        </Disclosure.Button>
                        <Disclosure.Panel
                          as="div"
                          className=" bg-whiteSmoke px-4 py-3 text-xs"
                        >
                          <div className="grid grid-cols-4 gap-3">
                            <FormCheck
                              onChange={(e) => handleCheckboxChange2(e)}
                              value="Black"
                              label="Black"
                              id="25"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange2(e)}
                              value="DarkCyan"
                              label="Purple"
                              id="26"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange(e)}
                              value="Brown"
                              label="Brown"
                              id="27"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange2(e)}
                              value="Light"
                              label="Light"
                              id="28"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange2(e)}
                              value="Blue"
                              label="Blue"
                              id="29"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange2(e)}
                              value="Red"
                              label="Red"
                              id="30"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange2(e)}
                              value="Silver"
                              label="Silver"
                              id="31"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange2(e)}
                              value="Dark"
                              label="Dark"
                              id="32"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange2(e)}
                              value="Pink"
                              label="Pink"
                              id="33"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange2(e)}
                              value="Green"
                              label="Green"
                              id="34"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange2(e)}
                              value="Orange"
                              label="Orange"
                              id="35"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange2(e)}
                              value="White"
                              label="White"
                              id="36"
                            />
                          </div>
                          {interiorshow && (
                            <div className="grid grid-cols-4 gap-3 mt-3">
                              <FormCheck
                                onChange={(e) => handleCheckboxChange2(e)}
                                value="Yellow"
                                label="Yellow"
                                id="37"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange2(e)}
                                value="Aqua"
                                label="Aqua"
                                id="38"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange2(e)}
                                value="Beige"
                                label="Beige"
                                id="39"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange2(e)}
                                value="Grey"
                                label="Grey"
                                id="40"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange2(e)}
                                value="Gold"
                                label="Gold"
                                id="41"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange2(e)}
                                value="Teal"
                                label="Teal"
                                id="42"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange2(e)}
                                value="Tan"
                                label="Tan"
                                id="43"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange2(e)}
                                value="DarkKhaki"
                                label="DarkKhaki"
                                id="44"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange2(e)}
                                value="Burgundy"
                                label="Burgundy"
                                id="45"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange2(e)}
                                value="DarkBlue"
                                label="DarkBlue"
                                id="46"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange2(e)}
                                value="DarkGreen"
                                label="DarkGreen"
                                id="47"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange2(e)}
                                value="DarkCyan"
                                label="DarkCyan"
                                id="48"
                              />
                            </div>
                          )}
                          <div className=" flex justify-center">
                            <button
                              onClick={() => {
                                setInteriorShow(!interiorshow);
                              }}
                              className="bg-white  py-2 px-6 rounded mt-3 underline text-reefGold"
                            >
                              {interiorshow ? "View Less" : "View More"}
                            </button>
                          </div>
                          <div className="flex justify-center">
                            <button
                              onClick={() => updateSortingForInteriorColor()}
                              className="bg-reefGold  py-2 px-6 rounded mt-3 text-white"
                            >
                              Filter
                            </button>
                          </div>
                        </Disclosure.Panel>
                      </>
                    )}
                  </Disclosure>
                </div>
              </div>
            </div>
          </>
        ) : null}

        {check === "car" ? (
          <>
            <div className="border-b">
              <div className="px-10 py-3">
                <div className="mb-3">
                  <Disclosure as="div" className={`mb-3`} defaultOpen={true}>
                    {({ open }) => (
                      <>
                        <Disclosure.Button
                          className={` w-full rounded py-3 px-6 gap-4 justify-between items-center flex ${
                            open && "mb-3"
                          }`}
                        >
                          <span className="text-xl">Technical Features</span>
                          <span className="flex-shrink-0">
                            {open ? (
                              <CloseDisclosure className="text-[#8D7C3B]" />
                            ) : (
                              <OpenDisclosure className="text-[#8D7C3B]" />
                            )}
                          </span>
                        </Disclosure.Button>
                        <Disclosure.Panel
                          as="div"
                          className=" bg-whiteSmoke px-4 py-3 text-xs"
                        >
                          <div className="grid grid-cols-2 gap-3">
                            <FormCheck
                              onChange={(e) => handleCheckboxChange3(e)}
                              value="4 Wheel Drive"
                              label="4 Wheel Drive"
                              id="49"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange3(e)}
                              value="All Wheel Drive"
                              label="All Wheel Drive"
                              id="50"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange3(e)}
                              value="Dual Exhaust"
                              label="Dual Exhaust"
                              id="51"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange3(e)}
                              value="Front Airbags"
                              label="Front Airbags"
                              id="52"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange3(e)}
                              value="Power Steering"
                              label="Power Steering"
                              id="53"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange3(e)}
                              value="Side Airbags"
                              label="Side Airbags"
                              id="54"
                            />
                          </div>
                          {technical && (
                            <div className="grid grid-cols-2 gap-3 mt-3">
                              <FormCheck
                                onChange={(e) => handleCheckboxChange3(e)}
                                value="DarkGreen"
                                label="All Wheel Steering"
                                id="55"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange3(e)}
                                value="Front Wheel Drive"
                                label="Front Wheel Drive"
                                id="56"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange3(e)}
                                value="Tiptronic Gears"
                                label="Tiptronic Gears"
                                id="57"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange3(e)}
                                value="Rear Wheel Drive"
                                label="Rear Wheel Drive"
                                id="58"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange3(e)}
                                value="N2O System"
                                label="N2O System"
                                id="59"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange3(e)}
                                value="Cruise Control"
                                label="Cruise Control"
                                id="60"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange3(e)}
                                value="Anti-Lock Brakers/ABS"
                                label="Anti-Lock Brakers/ABS"
                                id="61"
                              />
                            </div>
                          )}
                          <div className=" flex justify-center">
                            <button
                              onClick={() => {
                                setTechnical(!technical);
                              }}
                              className="bg-white  py-2 px-6 rounded mt-3 underline text-reefGold"
                            >
                              {technical ? "View Less" : "View More"}
                            </button>
                          </div>
                          <div className="flex justify-center">
                            <button
                              onClick={() =>
                                updateSortingForTechnicalFeatures()
                              }
                              className="bg-reefGold  py-2 px-6 rounded mt-3 text-white"
                            >
                              Filter
                            </button>
                          </div>
                        </Disclosure.Panel>
                      </>
                    )}
                  </Disclosure>
                  <Disclosure as="div" className={`mb-3`} defaultOpen={true}>
                    {({ open }) => (
                      <>
                        <Disclosure.Button
                          className={` w-full rounded py-3 px-6 gap-4 justify-between items-center flex ${
                            open && "mb-3"
                          }`}
                        >
                          <span className="text-xl">Extras</span>
                          <span className="flex-shrink-0">
                            {open ? (
                              <CloseDisclosure className="text-[#8D7C3B]" />
                            ) : (
                              <OpenDisclosure className="text-[#8D7C3B]" />
                            )}
                          </span>
                        </Disclosure.Button>
                        <Disclosure.Panel
                          as="div"
                          className=" bg-whiteSmoke px-4 py-3 text-xs"
                        >
                          <div className="grid grid-cols-2 gap-3">
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Aux Audio In"
                              label="Aux Audio In"
                              id="62"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Body Kit"
                              label="Body Kit"
                              id="63"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Am/Fm Radio"
                              label="Am/Fm Radio"
                              id="64"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Brush Guard"
                              label="Brush Guard"
                              id="65"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="CD Player"
                              label="CD Player"
                              id="66"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="DVD Player"
                              label="DVD Player"
                              id="67"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Keyless Entry"
                              label="Keyless Entry"
                              id="68"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Keyless Start"
                              label="Keyless Start"
                              id="69"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Off-Road Kit"
                              label="Off-Road Kit"
                              id="70"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Off-Road Tyres"
                              label="Off-Road Tyres"
                              id="71"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Power Mirrors"
                              label="Power Mirrors"
                              id="72"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Power Seats"
                              label="Power Seats"
                              id="73"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Premium Lights"
                              label="Premium Lights"
                              id="74"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Premium Paint"
                              label="Premium Paint"
                              id="75"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Roof Rack"
                              label="Roof Rack"
                              id="76"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Spoiler"
                              label="Spoiler"
                              id="78"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Air Conditioning"
                              label="Air Conditioning"
                              id="79"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Bluetooth System"
                              label="Bluetooth System"
                              id="80"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Cassette Player"
                              label="Cassette Player"
                              id="81"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Climate Control"
                              label="Climate Control"
                              id="82"
                            />
                          </div>
                          {extras && (
                            <div className="grid grid-cols-2 gap-3 mt-3">
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Fog Lights"
                                label="Fog Lights"
                                id="83"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Heated Seats"
                                label="Heated Seats"
                                id="84"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Leather Seats"
                                label="Leather Seats"
                                id="85"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Moonroof"
                                label="Moonroof"
                                id="86"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Parking Sensors"
                                label="Parking Sensors"
                                id="87"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Power Locks"
                                label="Power Locks"
                                id="88"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Power Sunroof"
                                label="Power Sunroof"
                                id="89"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Power Windows"
                                label="Power Windows"
                                id="91"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Racing Seats"
                                label="Racing Seats"
                                id="92"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Roof Rack"
                                label="Roof Rack"
                                id="93"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Sunroof"
                                label="Sunroof"
                                id="94"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="VHS Player"
                                label="VHS Player"
                                id="95"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Satellite Radios"
                                label="Satellite Radios"
                                id="96"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Rear View Camera"
                                label="Rear View Camera"
                                id="97"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Performace Tyres"
                                label="Performace Tyres"
                                id="98"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Cooled Seats"
                                label="Cooled Seats"
                                id="99"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Navigation System"
                                label="Navigation System"
                                id="100"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Premium Wheels/Rims"
                                label="Premium Wheels/Rims"
                                id="101"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Premium Sound System"
                                label="Premium Sound System"
                                id="102"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Alarm/Anti-Theft System"
                                label="Alarm/Anti-Theft System"
                                id="103"
                              />
                            </div>
                          )}
                          <div className=" flex justify-center">
                            <button
                              onClick={() => {
                                setExtras(!extras);
                              }}
                              className="bg-white  py-2 px-6 rounded mt-3 underline text-reefGold"
                            >
                              {extras ? "View Less" : "View More"}
                            </button>
                          </div>
                          <div className="flex justify-center">
                            <button
                              onClick={() => updateSortingForCarExtra()}
                              className="bg-reefGold  py-2 px-6 rounded mt-3 text-white"
                            >
                              Filter
                            </button>
                          </div>
                        </Disclosure.Panel>
                      </>
                    )}
                  </Disclosure>
                </div>
              </div>
            </div>
          </>
        ) : null}

        {check === "boat" ? (
          <>
            <div className="border-b">
              <div className="px-10 py-3">
                <div className="mb-3">
                  <Disclosure as="div" className={`mb-3`} defaultOpen={true}>
                    {({ open }) => (
                      <>
                        <Disclosure.Button
                          className={` w-full rounded py-3 px-6 gap-4 justify-between items-center flex ${
                            open && "mb-3"
                          }`}
                        >
                          <span className="text-xl">Extras</span>
                          <span className="flex-shrink-0">
                            {open ? (
                              <CloseDisclosure className="text-[#8D7C3B]" />
                            ) : (
                              <OpenDisclosure className="text-[#8D7C3B]" />
                            )}
                          </span>
                        </Disclosure.Button>
                        <Disclosure.Panel
                          as="div"
                          className=" bg-whiteSmoke px-4 py-3 text-xs"
                        >
                          <div className="grid grid-cols-2 gap-3">
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Steel"
                              label="Steel"
                              id="1111"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Aluminum"
                              label="Aluminum"
                              id="1112"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Fibre-Reinforced"
                              label="Fibre-Reinforced"
                              id="1113"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Plastic"
                              label="Plastic"
                              id="1114"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Plywood"
                              label="Plywood"
                              id="1115"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Fibre"
                              label="Fibre"
                              id="1116"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Resin"
                              label="Resin"
                              id="1117"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Ferrocement"
                              label="Ferrocement"
                              id="1118"
                            />

                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Gelcoat"
                              label="Gelcoat"
                              id="110"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Polyvinyl Chloride"
                              label="Polyvinyl Chloride"
                              id="111"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Aux Audio In"
                              label="Aux Audio In"
                              id="112"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="CD Player"
                              label="CD Player"
                              id="113"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Premium Light"
                              label="Premium Light"
                              id="114"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="DVD Player"
                              label="DVD Player"
                              id="115"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Power Seat"
                              label="Power Seat"
                              id="116"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Private Pool"
                              label="Private Pool"
                              id="117"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Business Center"
                              label="Business Center"
                              id="118"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Racing Seats"
                              label="Racing Seats"
                              id="119"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange4(e)}
                              value="Prayer Room"
                              label="Prayer Room"
                              id="120"
                            />
                          </div>
                          {extras && (
                            <div className="grid grid-cols-2 gap-3 mt-3">
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Private Pool"
                                label="Private Pool"
                                id="119"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Satellite / Cable TV"
                                label="Satellite / Cable TV"
                                id="210"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Business Center"
                                label="Business Center"
                                id="1219"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Kids Play Area"
                                label="Kids Play Area"
                                id="2210"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Racing Seats"
                                label="Racing Seats"
                                id="1219"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Prayer Room"
                                label="Prayer Room"
                                id="2210"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Bluetooth System"
                                label="Bluetooth System"
                                id="1219"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Fibre-reinforced plastic"
                                label="Fibre-reinforced plastic"
                                id="7210"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange4(e)}
                                value="Premium Sound System"
                                label="Premium Sound System"
                                id="8210"
                              />
                            </div>
                          )}
                          <div className=" flex justify-center">
                            <button
                              onClick={() => {
                                setExtras(!extras);
                              }}
                              className="bg-white  py-2 px-6 rounded mt-3 underline text-reefGold"
                            >
                              {extras ? "View Less" : "View More"}
                            </button>
                          </div>
                          <div className="flex justify-center">
                            <button
                              onClick={() => updateSortingForCarExtra()}
                              className="bg-reefGold  py-2 px-6 rounded mt-3 text-white"
                            >
                              Filter
                            </button>
                          </div>
                        </Disclosure.Panel>
                      </>
                    )}
                  </Disclosure>
                </div>
              </div>
            </div>
          </>
        ) : null}

        {check === "jewelry" ? (
          <>
            {" "}
            <div className="border-b">
              <div className="px-10 py-3">
                <p className="text-xl mb-3">Grams</p>
                <Disclosure as="div" className={`disclosure`}>
                  {({ open }) => (
                    <>
                      <Disclosure.Button
                        className={`w-full bg-whiteSmoke rounded py-3 px-6 gap-4 justify-between items-center flex ${
                          open && "mb-3"
                        }`}
                      >
                        <span
                          className="text-base cursor-pointer"
                          onClick={() => updateSortingForGrams("Any")}
                        >
                          Any
                        </span>
                        <span className="flex-shrink-0">
                          {open ? (
                            <CloseDisclosure className="text-[#8D7C3B]" />
                          ) : (
                            <OpenDisclosure className="text-[#8D7C3B]" />
                          )}
                        </span>
                      </Disclosure.Button>
                      <Disclosure.Panel as="div" className="px-8 text-sm">
                        <p
                          className="cursor-pointer"
                          onClick={() => updateSortingForGrams("Any")}
                        >
                          Any
                        </p>
                        <p
                          onClick={() => updateSortingForGrams("5.2")}
                          className="cursor-pointer"
                        >
                          5.2
                        </p>
                        <p
                          onClick={() => updateSortingForGrams("5")}
                          className="cursor-pointer"
                        >
                          5.5
                        </p>
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
              </div>
            </div>
            <div className="border-b ">
              <div className="px-10 py-3">
                <div className="mb-3">
                  <Disclosure as="div" className={`mb-3`} defaultOpen={true}>
                    {({ open }) => (
                      <>
                        <Disclosure.Button
                          className={` w-full rounded py-3 px-6 gap-4 justify-between items-center flex ${
                            open && "mb-3"
                          }`}
                        >
                          <span className="text-xl">Materials</span>
                          <span className="flex-shrink-0">
                            {open ? (
                              <CloseDisclosure className="text-[#8D7C3B]" />
                            ) : (
                              <OpenDisclosure className="text-[#8D7C3B]" />
                            )}
                          </span>
                        </Disclosure.Button>
                        <Disclosure.Panel
                          as="div"
                          className=" bg-whiteSmoke px-4 py-3 text-xs"
                        >
                          <div className="grid grid-cols-2 gap-3">
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Amber"
                              label="Amber"
                              id="1"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="CX"
                              label="CX"
                              id="2"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Breads"
                              label="Breads"
                              id="3"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Crystal"
                              label="Crystal"
                              id="4"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Plastic"
                              label="Plastic"
                              id="5"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Platinum"
                              label="Platinum"
                              id="6"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Steel"
                              label="Steel"
                              id="7"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Titanium"
                              label="Titanium"
                              id="8"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Bronze"
                              label="Bronze"
                              id="9"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Ceramic"
                              label="Ceramic"
                              id="10"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Diamond"
                              label="Diamond"
                              id="11"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Gemstone"
                              label="Gemstone"
                              id="12"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Rhinestones"
                              label="Rhinestones"
                              id="13"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Rubber"
                              label="Rubber"
                              id="14"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="White Gold"
                              label="White Gold"
                              id="15"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Woord"
                              label="Woord"
                              id="16"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Shell"
                              label="Shell"
                              id="17"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Bone"
                              label="Bone"
                              id="18"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Coral"
                              label="Coral"
                              id="19"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Leather"
                              label="Leather"
                              id="20"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Silver"
                              label="Silver"
                              id="21"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Yellow Gold"
                              label="Yellow Gold"
                              id="22"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Other Material"
                              label="Other Material"
                              id="23"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Other Metal"
                              label="Other Metal"
                              id="24"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Semi Precious"
                              label="Semi Precious"
                              id="25"
                            />
                            <FormCheck
                              onChange={(e) => handleCheckboxChange5(e)}
                              value="Birth Stones"
                              label="Birth Stones"
                              id="26"
                            />
                          </div>
                          {extras && (
                            <div className="grid grid-cols-2 gap-3 mt-3">
                              <FormCheck
                                onChange={(e) => handleCheckboxChange5(e)}
                                value="Birth Stoness"
                                label="Birth Stones"
                                id="27"
                              />
                              <FormCheck
                                onChange={(e) => handleCheckboxChange5(e)}
                                value="Semi Precious"
                                label="Semi Precious"
                                id="28"
                              />
                            </div>
                          )}
                          <div className=" flex justify-center">
                            <button
                              onClick={() => {
                                setExtras(!extras);
                              }}
                              className="bg-white  py-2 px-6 rounded mt-3 underline text-reefGold"
                            >
                              {extras ? "View Less" : "View More"}
                            </button>
                          </div>
                          <div className="flex justify-center">
                            <button
                              onClick={() => updateSortingForMaterial()}
                              className="bg-reefGold  py-2 px-6 rounded mt-3 text-white"
                            >
                              Filter
                            </button>
                          </div>
                        </Disclosure.Panel>
                      </>
                    )}
                  </Disclosure>
                </div>
              </div>
            </div>
          </>
        ) : null}
      </aside>
    </div>
  );
};
